@@ -4,10 +4,6 @@
 # In[ ]:
 
 import pandas as pd
-
-def add_constant(df:pd.DataFrame) -> None:
-    df['constant'] = 1
-    
     
 def add_day_of_week_dummies(df:pd.DataFrame, date_label:str=None):
     if date_label is None:
@@ -17,7 +13,7 @@ def add_day_of_week_dummies(df:pd.DataFrame, date_label:str=None):
         
     else:
         dates_index = pd.to_datetime(df[date_label],format='%Y/%m/%d')
-    add_constant(df)
+    df['constant'] = 1
     df['day_of_week'] = dates_index.dt.day_name()
     df['day_of_week'] = df['day_of_week'].str.lower()
     dummies = pd.get_dummies(df['day_of_week'])       
